Crate sszb_derive

Crate sszb_derive 

Provides procedural derive macros for the Encode and Decode traits of the eth2_sszb crate.

Supports field attributes, see each derive macro for more information.

Derive Macros

Decode
Derive sszb::Decode for a struct or enum.
Encode
Implements sszb::Encode for some struct or enum.